@@ -17,13 +17,15 @@ import paraselene.tag.*;
 class TagSource extends Tag implements Source {
 	private static long seq = 0;
 	private String val_name;
+	private String html_name;
 
 	String getTagString() {
 		return new Text( getFirstTag() ).toString( HTMLPart.StringMode.BODY );
 	}
 
-	TagSource( String n, boolean single_f ) {
+	TagSource( String html, String n, boolean single_f ) {
 		super( n, single_f );
+		html_name = html;
 		val_name = "tag" + Long.toString( seq );
 		seq++;
 		if ( seq < 0 )	seq = 0;
@@ -123,6 +125,7 @@ class TagSource extends Tag implements Source {
 		if ( uri_f ) {
 			try {
 				if ( val.isEmpty() )	val = "#";
+				if ( val.equals( "." ) )	val = html_name;
 				URI	uri = new URI( val );
 				val = Linker.readme.resolvePath( uri );
 			}
