@@ -224,7 +224,7 @@ class LocationOutput extends OutputCall {
 		if ( !forward.isLeave() ) {
 			fw = data.redirect( out, forward, req );
 		}
-		String	url = Supervisor.makeWithSessionURI( fw.getRedirectURI().toString(), null, null );
+		String	url = fw.getRedirectURI().toString();
 		Option.trace( "%s redirect JSON", url );
 		return new PostBack[] { new PostBack( url ) };
 	}
